@@ -1,8 +1,13 @@
 class Specinfra::Command::Aix::Base::Group < Specinfra::Command::Base::Group
   class << self
-    def check_has_gid(group, gid)
-      regexp = "^#{group}"
-      "cat etc/group | grep -w -- #{escape(regexp)} | cut -f 3 -d ':' | grep -w -- #{escape(gid)}"
+
+    def check_exists(group)
+      "lsgroup #{escape(group)}"
     end
+
+    def check_has_gid(group, gid)
+      "lsgroup -a id #{escape(group)} | cut -f 2 -d '=' | grep -w -- #{escape(gid)}"
+    end
+
   end
 end
